@@ -97,7 +97,7 @@ def tidy_up(fn, kl, kt):
 def check_mth(mm):
     if not 1 <= int(mm) <= 12:
         print("ERROR: Enter month between 01 and 12")
-        sys.exit()
+        sys.exit(0)
 
 def check_exists(fn):
     # check a required file exist to avoid a more obscure error in pdfTeX if "-v" not used...
@@ -113,7 +113,7 @@ def check_date(year, month, day):
         day_count_for_month[2] = 29
     if not (1 <= mm <= 12 and 1 <= int(day) <= day_count_for_month[mm]):
         print("ERROR: Enter a valid date")
-        sys.exit()
+        sys.exit(0)
 
 def check_years(yearfr, yearto):
     global yrmin, yrmax
@@ -387,7 +387,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                     if ss.lower() != 'x': sErr = True
                 if sErr:
                     print("ERROR: Incorrect data or format")
-                    sys.exit()
+                    sys.exit(0)
 
             else:
                 if len(ss) not in [2,3,4,8,9]: sErr = True
@@ -401,7 +401,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
 
                 if sErr:
                     print("ERROR: Incorrect data or format")
-                    sys.exit()
+                    sys.exit(0)
 
                 if len(ss) == 2:
                     dd = "01"
@@ -450,11 +450,11 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                     if len(nn) > 0:
                         if not nn.isnumeric():
                             print("ERROR: Not a number")
-                            sys.exit()
+                            sys.exit(0)
                         daystoprocess = int(nn)
                         if daystoprocess > 300:
                             print("ERROR: 'Days to process' not <= 300")
-                            sys.exit()
+                            sys.exit(0)
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         elif int(s) == 5:   # for Lunar Distance charts only
 #   Due to the lengthy calculations LD charts for a whole year is not supported.
@@ -484,7 +484,7 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
                 elif not ss.isnumeric(): sErr = True
                 if sErr:
                     print("ERROR: Enter numeric digits in the correct format")
-                    sys.exit()
+                    sys.exit(0)
                 if len(ss) == 2:
                     dd = "01"
                     mm = ss[0:2]
@@ -513,16 +513,16 @@ if __name__ == '__main__':      # required for Windows multiprocessing compatibi
 
                 if daystoprocess == 0:
                     daystoprocess = 1       # default
-                    s = input("""  Enter number of days to process from starting date:
+                    nn = input("""  Enter number of days to process from starting date:
 """)
-                    if len(s) > 0:
-                        if not s.isnumeric():
+                    if len(nn) > 0:
+                        if not nn.isnumeric():
                             print("ERROR: Not a number")
-                            sys.exit()
-                        daystoprocess = int(s)
+                            sys.exit(0)
+                        daystoprocess = int(nn)
                         if daystoprocess > 50:
                             print("ERROR: 'Days to process' not <= 50")
-                            sys.exit()
+                            sys.exit(0)
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         if s in set(['1', '2']):
             tsin = input("""  What table style is required?:\n
