@@ -18,16 +18,17 @@
 
 # This contains the majority of functions that calculate values for the Nautical Almanac
 
-# Standard library imports
+###### Standard library imports ######
 import datetime
 import time         # 00000 - stopwatch elements
 import math
 import os
-import errno        # NEW April 2022
+import errno
 import socket
-from urllib.request import urlopen  # NEW April 2022
+import sys			# required for .stdout.write()
+from urllib.request import urlopen
 
-# Third party imports
+###### Third party imports ######
 from skyfield import VERSION
 from skyfield.api import Loader
 from skyfield.api import Topos, Star
@@ -37,12 +38,12 @@ from skyfield.data import hipparcos
 from skyfield.magnitudelib import planetary_magnitude
 import numpy as np
 
-# Local application imports
+###### Local application imports ######
 from sfalmanac.lib import config as config
 
-#----------------------
-#   initialization
-#----------------------
+#---------------------------
+#   Module initialization
+#---------------------------
 
 hour_of_day = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23]
 next_hour_of_day = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24]
@@ -94,7 +95,8 @@ def testIERSserver(filename):
     return True     # server works
 
 def downloadUSNO(path, filename):
-    print("Downloading from USNO...", end ="")
+    sys.stdout.write("Downloading EOP data from USNO...")
+    sys.stdout.flush()
     filepath = os.path.join(path, filename)
     url = "https://maia.usno.navy.mil/ser7/" + filename
     connection = urlopen(url)
@@ -102,7 +104,7 @@ def downloadUSNO(path, filename):
 
     # Claim our own unique download filename.
 
-    tempbase = tempname = path + '.download'
+    tempbase = tempname = path + filename + '.download'
     flags = getattr(os, 'O_BINARY', 0) | os.O_CREAT | os.O_EXCL | os.O_RDWR
     i = 1
     while True:
@@ -140,7 +142,8 @@ def downloadUSNO(path, filename):
     except Exception as e:
         raise IOError('error renaming {0} to {1} - {2}'.format(tempname, filepath, e))
 
-    print("done.")
+    sys.stdout.write("done.\n")
+    sys.stdout.flush()
 
 def init_sf(spad):
     global ts, eph, earth, moon, sun, venus, mars, jupiter, saturn, df
@@ -191,9 +194,9 @@ def init_sf(spad):
 
     return ts
 
-#----------------------
-#   internal methods
-#----------------------
+#------------------------
+#   internal functions
+#------------------------
 
 def norm(delta):
     # normalize the angle between 0° and 360°
@@ -804,6 +807,10 @@ def stellar_info(d):        # used in starstab
         out.append([name,sha,decl])
     return out
 
+#-----------------------
+#   stellar data
+#-----------------------
+
 # List of navigational stars with Hipparcos Catalog Number
 db = """
 Alpheratz,677
@@ -955,51 +962,6 @@ def daylength(topos, degBelowHorizon):
     is_sun_up_at.rough_period = 0.5  # twice a day
     return is_sun_up_at
 
-##UNUSED##
-# create a list of 'sun above/below horizon' states per Latitude per Normal/Civil/Naut...
-#global sunvisible
-#sunvisible = [[None]*3 for i in range(31)]	# sunvisible[0][0] up to sunvisible[30][2]
-
-##UNUSED - only called by getsunstate (obsolete) ##
-def sunstate(ndx, h):
-    # return the current sunstate (if known)
-    out = '--:--'
-    if sunvisible[ndx][h] == True:
-        out = r'''\begin{tikzpicture}\draw (0,0) rectangle (12pt,4pt);\end{tikzpicture}'''
-    if sunvisible[ndx][h] == False:
-        out = r'''\rule{12Pt}{4Pt}'''
-    return out
-
-##UNUSED - poor algorithm - replaced by midnightsun ##
-def getsunstate(dt, lat, hemisph, horizon, j):
-    # populate the sun state (visible or not) for the specified date & latitude
-    # note: the first parameter 'dt' is already a datetime 30 seconds before midnight
-    # note: getsunstate is called when there is neither a sunrise nor a sunset on 'dt'
-
-    i = config.lat.index(lat)
-    lats = '{:3.1f} {}'.format(abs(lat), hemisph)
-    locn = Topos(lats, '0.0 E')
-    t0 = ts.ut1(dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second)
-    # clear the value as the sun state is not tracked daily...
-    sunvisible[i][j] = None
-
-    # search for the next sunrise or sunset (returned in sunstate[0] and y[0])
-    while sunvisible[i][j] == None:
-        t0 = ts.ut1(dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second)
-        dt += datetime.timedelta(days=1)
-        t9 = ts.ut1(dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second)
-        start00 = time.time()                   # 00000
-        sunstate, y = almanac.find_discrete(t0, t9, daylength(locn, horizon))
-        config.stopwatch2 += time.time()-start00 # 00000
-        if len(sunstate) > 0:
-
-            if y[0]:
-                sunvisible[i][j] = False
-            else:
-                sunvisible[i][j] = True
-
-    return
-
 #-------------------------
 #   MOONRISE/-SET table
 #-------------------------
@@ -1028,7 +990,6 @@ MDndx = MDlen - 1           # index to latest added date (initially 0 will be ch
 #       item[1][2:3] ... the middle character is 'finalstate' ... 'n' = above horizon; 'v' = below horizon
 np_array = np.ndarray(shape=(MDlen,31,2), dtype=np.dtype('U5'))
 
-##NEW##
 def getHorizon(t):
     # calculate the angle of the moon below the horizon at moonrise/set
 
@@ -1041,7 +1002,6 @@ def getHorizon(t):
 
     return horizon
 
-##NEW##
 def fetchMoonData(d, tFrom, tNoon, tTo, i, lats, hFlag = False, round2seconds=False):
     # calculate & store moon data (rise/set times) or fetch data if pre-calculated.
     # --- THIS IMPROVES PERFORMANCE BY AVOIDING DUPLICATE COSTLY CALCULATIONS AS ---
@@ -1309,7 +1269,6 @@ def getmoonstate(dt, lat, hemisph):
 
     return
 
-##NEW##
 def moonset_no_rise(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, round2seconds=False):
     # if moonset but no moonrise...
     msg = ""
@@ -1328,7 +1287,6 @@ def moonset_no_rise(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i,
         out = r'''\raisebox{0.24ex}{\boldmath$\cdot\cdot$~\boldmath$\cdot\cdot$}'''
     return out
 
-##NEW##
 def moonrise_no_set(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, round2seconds=False):
     # if moonrise but no moonset...
     msg = ""
@@ -1345,7 +1303,6 @@ def moonrise_no_set(date, lat, prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i,
         out = r'''\raisebox{0.24ex}{\boldmath$\cdot\cdot$~\boldmath$\cdot\cdot$}'''
     return out
 
-##NEW##
 def seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, round2seconds=False):
     # for the specified date & latitude ...
     # return -1 if there is NO MOONSET yesterday
@@ -1369,7 +1326,6 @@ def seek_moonset(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, round2se
 
     return m_set_t
 
-##NEW##
 def seek_moonrise(prday, t9, t9noon, t0, nxday, t1, t1noon, t2, i, lats, round2seconds=False):
     # return -1 if there is NO MOONRISE yesterday
     # return +1 if there is NO MOONRISE tomorrow
@@ -1671,7 +1627,10 @@ def find_transit2(d, ghaList, modeLT):
 
     # again locate it more precisely (to the second)
     iLoops = 0
-    sec_start = max(0, int((360-prev_gha)/0.25*60.0)-1)
+    # NOTE: 0.25 in the sec_start equation below works for every day except 24.08.2063 (Lower Transit)
+    #       0.26 is a better choice
+    #val = (360-prev_gha)/0.25*60.0
+    sec_start = max(0, int((360-prev_gha)/0.26*60.0)-1)
     for se in range(sec_start,60):      # 0 to 59 max
         gha = getGHA(d, hr, mi, se+1)   # GHA on the second after the event
         gha_time = "{:02d}:{:02d}:{:02d}".format(hr,mi,se+1)
@@ -1679,6 +1638,7 @@ def find_transit2(d, ghaList, modeLT):
             gha = GHAcolong(gha)
         if(gha < prev_gha):
             if(iLoops == 0 and se > 0): raise ValueError('ERROR: sec_start ({}) too large on {} at {} ({})'.format(se, d, gha_time, txt))
+            #if(iLoops == 0 and se > 0): raise ValueError('ERROR: sec_start ({}) too large on {} at {} ({}) val = {:f}'.format(se, d, gha_time, txt, val))
             break       # break when event detected ('hr:mi:se' is before event)
         prev_gha = gha  # GHA each second before the event
         prev_time = "{:02d}:{:02d}:{:02d}".format(hr,mi,se+1)
@@ -1947,4 +1907,4 @@ def find_new_moon(d):       # used in doublepage
         WaxingMoon = True
         if PreviousFullMoon > PreviousNewMoon:
             WaxingMoon = False
-    return
+    return
\ No newline at end of file
