@@ -24,6 +24,7 @@ import math
 import os
 import errno
 import socket
+import sys			# required for .stdout.write()
 from urllib.request import urlopen
 
 ###### Third party imports ######
@@ -142,7 +143,6 @@ def downloadUSNO(path, filename):
     except Exception as e:
         raise IOError('error renaming {0} to {1} - {2}'.format(tempname, filepath, e))
 
-    print("done.")
     sys.stdout.write("done.\n")
     sys.stdout.flush()
 
@@ -488,6 +488,26 @@ def find_transit(d, ghaList, modeLT):   # used in moontab
 ####    return transit_time, prev_gha, prev_time, gha, gha_time, mid_gha, mid_time
 
 
+#-------------------------------------------------------------
+#   Sun and Moon calculations  (Lunar Distance tables only)
+#-------------------------------------------------------------
+
+def sunSD(d):
+    # compute semi-diameter of sun at 0h and 23h
+    sdsm = [0.0, 0.0]
+    i = 0
+    for hh in [0, 23]:
+        t00 = ts.ut1(d.year, d.month, d.day, hh, 0, 0)
+        position = earth.at(t00).observe(sun)
+        distance = position.apparent().radec(epoch='date')[2]
+        dist_km = distance.km
+        # volumetric mean radius of sun = 695700 km
+        sds = math.degrees(math.atan(695700.0 / dist_km))
+        sdsm[i] = "{:0.1f}".format(sds * 60)   # convert to minutes of arc
+        i += 1
+
+    return sdsm
+
 #-------------------------------------------------------------
 #   Sun and Moon calculations  (Lunar Distance charts only)
 #-------------------------------------------------------------
